# -*- coding: utf-8 -*-

from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from thx.core.admin import UserAdminMixin

from .models import SectionSettings


class SectionAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug', 'template_name')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        try:
            return settings.SECTION_ADMIN[obj.template_name]
        except Exception as e:
            return super().get_fieldsets(request, obj)


class BoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug')
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return settings.BOX_ADMIN[parent.template_name]
            except Exception as e:
                pass

            try:
                return settings.BOX_ADMIN[obj.template_name]
            except Exception as exc:
                return settings.BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)


class ModelBoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    filter_horizontal = ('tags',)
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return settings.MODEL_BOX_ADMIN[parent.template_name]
            except Exception as e:
                pass

            try:
                return settings.MODEL_BOX_ADMIN[obj.template_name]
            except Exception as exc:
                return settings.MODEL_BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)


class FilterBoxAdminMixin(UserAdminMixin):
    fieldsets = (
        (_('general information'), {
            'fields': ('status', 'title', 'slug', 'tags',)
        }),
        (_('logs admin'), {
            'classes': ('collapse',),
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify')
        }),
    )
    readonly_fields = ('creator', 'date_create', 'last_modifier', 'date_last_modify')
    filter_horizontal = ('tags',)
    prepopulated_fields = {'slug': ('title',)}

    def get_fieldsets(self, request, obj=None):
        if obj:
            try:
                parent = SectionSettings.objects.get(pk=obj.parent_id)
                return settings.FILTER_BOX_ADMIN[parent.template_name]
            except Exception as e:
                pass

            try:
                return settings.FILTER_BOX_ADMIN[obj.template_name]
            except Exception as exc:
                return settings.FILTER_BOX_ADMIN_NO_PARENT

        return super().get_fieldsets(request, obj)
