# -*- coding: utf-8 -*-

from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import admin
from . import models


@plugin_pool.register_plugin
class SectionPlugin(admin.SectionAdminMixin, CMSPluginBase):
    model = models.SectionSettings
    module = _("box")
    name = _("section")
    render_template = "cms/empty.html"
    allow_children = True,
    child_classes = ['BoxPlugin', 'ModelBoxPlugin', 'FilterBoxPlugin', ]

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


@plugin_pool.register_plugin
class BoxPlugin(admin.BoxAdminMixin, CMSPluginBase):
    model = models.BoxSettings
    module = _("box")
    name = _("box")
    render_template = "cms/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name

        context.update({
            'instance': instance,
            'placeholder': placeholder,
        })
        return context


@plugin_pool.register_plugin
class ModelBoxPlugin(admin.ModelBoxAdminMixin, CMSPluginBase):
    model = models.ModelBoxSettings
    module = _("box")
    name = _("model box")
    render_template = "cms/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name
        objects = instance.get_objects()

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'objects': objects,
        })
        return context


@plugin_pool.register_plugin
class FilterBoxPlugin(admin.FilterBoxAdminMixin, CMSPluginBase):
    model = models.FilterBoxSettings
    module = _("box")
    name = _("filter box")
    render_template = "cms/empty.html"

    def render(self, context, instance, placeholder):
        if instance.status == 0:
            return context

        self.render_template = instance.template_name
        tags = instance.tags.all()

        context.update({
            'instance': instance,
            'placeholder': placeholder,
            'tags': tags,
        })
        return context
